@@ -10,23 +10,23 @@ pytest_plugins = ["pytester"]
 @pytest.fixture
 def fixture_path_relative_dense(testdir):
     for i_mod in range(10):
-        test_name = testdir.tmpdir.join("test_relative_dense_perf{}.py".format(i_mod))
+        test_name = testdir.tmpdir.join(f"test_relative_dense_perf{i_mod}.py")
         test_contents = "import pytest\n"
         for i in range(90):
             test_contents += dedent(
-                """
-                @pytest.mark.order(after="test_{}")
-                def test_{}():
+                f"""
+                @pytest.mark.order(after="test_{i + 10}")
+                def test_{i}():
                     assert True
                 """
-            ).format(i + 10, i)
+            )
         for i in range(10):
             test_contents += dedent(
-                """
-                def test_{}():
+                f"""
+                def test_{i + 90}():
                     assert True
                 """
-            ).format(i + 90)
+            )
         test_name.write(test_contents)
     yield testdir
 
